@@ -109,30 +109,6 @@ GdkPixbuf *crop_resize(GdkPixbuf *src, int width, int height) {
     return dest;
 }
 
-gboolean can_crop_file(const gchar *file, gboolean *can_scale)
-{
-    int width = 0, height = 0;
-    GdkPixbufFormat *format;
-    
-    *can_scale = FALSE;
-    
-    format = gdk_pixbuf_get_file_info(file, &width, &height);
-    
-    if(format) {
-        *can_scale = gdk_pixbuf_format_is_scalable(format);
-/*
-        if (width > MAX_SRC_WIDTH || height > MAX_SRC_HEIGHT) {
-            g_warning("Can't crop/scale due to memory restriction: "
-                      "(%d x %d) > (%d x %d)",
-                      width, height, MAX_SRC_WIDTH, MAX_SRC_HEIGHT);
-            *can_scale = FALSE;
-            return FALSE;
-        }*/
-    }
-    
-    return TRUE;
-}
-
 static void size_prepared(GdkPixbufLoader *loader,
   gint width, gint height, gpointer user_data)
 {
@@ -170,11 +146,7 @@ GdkPixbuf *create_thumb(const gchar *local_file, const gchar *mime_type,
     guint width, guint height, OssoThumbnailFlags flags,
     gchar ***opt_keys, gchar ***opt_values, GError **error)
 {
-    gboolean can_crop = TRUE, can_scale = TRUE;
-    
-    can_crop = can_crop_file(local_file, &can_scale);
-
-    if((flags & OSSO_THUMBNAIL_FLAG_CROP) && can_crop) {
+    if((flags & OSSO_THUMBNAIL_FLAG_CROP)) {
        GdkPixbuf *pixbuf, *result = NULL;
        GdkPixbufLoader *loader;
        guchar buffer[2048];
@@ -213,7 +185,7 @@ cleanup:
        g_object_unref(loader);
        return result;
 
-    } else if(can_scale) {
+    } else {
        GdkPixbuf *pixbuf;
        GError *error = NULL;
 
